@@ -1,6 +1,7 @@
 from .constraint import Constraint
 from .expression import Expression, null_expression
 from .function import Function
+from .psd_matrix import PSDMatrix
 from .pep import PEP
 from .point import Point, null_point
 
@@ -12,6 +13,7 @@ __all__ = ['examples',
            'constraint', 'Constraint',
            'expression', 'Expression', 'null_expression',
            'function', 'Function',
+           'psd_matrix', 'PSDMatrix',
            'pep', 'PEP',
            'point', 'Point', 'null_point',
            ]
