@@ -46,7 +46,7 @@ def wc_gradient_descent_lyapunov_2(L, gamma, n, verbose=1):
         n (int):  current iteration number.
         verbose (int): Level of information details to print.
                         
-                        - 1: No verbose at all.
+                        - -1: No verbose at all.
                         - 0: This example's output.
                         - 1: This example's output + PEPit information.
                         - 2: This example's output + PEPit information + CVXPY details.
@@ -57,19 +57,20 @@ def wc_gradient_descent_lyapunov_2(L, gamma, n, verbose=1):
 
     Examples:
         >>> L = 1
-        >>> gamma = 1 / L
-        >>> pepit_tau, theoretical_tau = wc_gradient_descent_lyapunov_2(L=L, gamma=gamma, n=10, verbose=1)
+        >>> pepit_tau, theoretical_tau = wc_gradient_descent_lyapunov_2(L=L, gamma=1 / L, n=10, verbose=1)
         (PEPit) Setting up the problem: size of the main PSD matrix: 4x4
         (PEPit) Setting up the problem: performance measure is minimum of 1 element(s)
-        (PEPit) Setting up the problem: initial conditions (0 constraint(s) added)
+        (PEPit) Setting up the problem: Adding initial conditions and general constraints ...
+        (PEPit) Setting up the problem: initial conditions and general constraints (0 constraint(s) added)
         (PEPit) Setting up the problem: interpolation conditions for 1 function(s)
-		         function 1 : 6 constraint(s) added
+                         function 1 : Adding 6 scalar constraint(s) ...
+                         function 1 : 6 scalar constraint(s) added
         (PEPit) Compiling SDP
         (PEPit) Calling SDP solver
-        (PEPit) Solver status: optimal (solver: MOSEK); optimal value: 6.173593192215776e-09
-        *** Example file: worst-case performance of gradient descent with fixed step-size for a given Lyapunov function***
-            PEPit guarantee:		V_(n+1) - V_(n) <= 6.17359e-09
-            Theoretical guarantee:	V_(n+1) - V_(n) <= 0.0
+        (PEPit) Solver status: optimal (solver: SCS); optimal value: 1.894425729310791e-17
+        *** Example file: worst-case performance of gradient descent with fixed step size for a given Lyapunov function***
+                PEPit guarantee:        V_(n+1) - V_(n) <= 1.89443e-17
+                Theoretical guarantee:  V_(n+1) - V_(n) <= 0.0
 
     """
 
@@ -103,7 +104,7 @@ def wc_gradient_descent_lyapunov_2(L, gamma, n, verbose=1):
     pepit_tau = problem.solve(verbose=pepit_verbose)
 
     # Compute theoretical guarantee (for comparison)
-    if gamma == 1/L:
+    if gamma == 1 / L:
         theoretical_tau = 0.
     else:
         theoretical_tau = None
@@ -114,7 +115,7 @@ def wc_gradient_descent_lyapunov_2(L, gamma, n, verbose=1):
               ' worst-case performance of gradient descent with fixed step size for a given Lyapunov function***')
         print('\tPEPit guarantee:\t'
               'V_(n+1) - V_(n) <= {:.6}'.format(pepit_tau))
-        if gamma == 1/L:
+        if gamma == 1 / L:
             print('\tTheoretical guarantee:\t'
                   'V_(n+1) - V_(n) <= {:.6}'.format(theoretical_tau))
 
@@ -123,7 +124,5 @@ def wc_gradient_descent_lyapunov_2(L, gamma, n, verbose=1):
 
 
 if __name__ == "__main__":
-
     L = 1
-    gamma = 1 / L
-    pepit_tau, theoretical_tau = wc_gradient_descent_lyapunov_2(L=L, gamma=gamma, n=10, verbose=1)
+    pepit_tau, theoretical_tau = wc_gradient_descent_lyapunov_2(L=L, gamma=1 / L, n=10, verbose=1)
