@@ -3,6 +3,7 @@ from .accelerated_gradient_strongly_convex import wc_accelerated_gradient_strong
 from .accelerated_proximal_point import wc_accelerated_proximal_point
 from .conjugate_gradient import wc_conjugate_gradient
 from .conjugate_gradient_qg_convex import wc_conjugate_gradient_qg_convex
+from .epsilon_subgradient_method import wc_epsilon_subgradient_method
 from .gradient_descent import wc_gradient_descent
 from .gradient_descent_qg_convex import wc_gradient_descent_qg_convex
 from .gradient_descent_qg_convex_decreasing import wc_gradient_descent_qg_convex_decreasing
@@ -12,20 +13,21 @@ from .heavy_ball_momentum_qg_convex import wc_heavy_ball_momentum_qg_convex
 from .inexact_accelerated_gradient import wc_inexact_accelerated_gradient
 from .inexact_gradient_descent import wc_inexact_gradient_descent
 from .inexact_gradient_exact_line_search import wc_inexact_gradient_exact_line_search
+from .information_theoretic_exact_method import wc_information_theoretic
 from .optimized_gradient import wc_optimized_gradient
+from .optimized_gradient_for_gradient import wc_optimized_gradient_for_gradient
 from .proximal_point import wc_proximal_point
 from .robust_momentum import wc_robust_momentum
 from .subgradient_method import wc_subgradient_method
 from .subgradient_method_rsi_eb import wc_subgradient_method_rsi_eb
 from .triple_momentum import wc_triple_momentum
-from .information_theoretic_exact_method import wc_information_theoretic
-from .optimized_gradient_for_gradient import wc_optimized_gradient_for_gradient
 
 __all__ = ['accelerated_gradient_convex', 'wc_accelerated_gradient_convex',
            'accelerated_gradient_strongly_convex', 'wc_accelerated_gradient_strongly_convex',
            'accelerated_proximal_point', 'wc_accelerated_proximal_point',
            'conjugate_gradient', 'wc_conjugate_gradient',
            'conjugate_gradient_qg_convex', 'wc_conjugate_gradient_qg_convex',
+           'epsilon_subgradient_method', 'wc_epsilon_subgradient_method',
            'gradient_descent', 'wc_gradient_descent',
            'gradient_descent_qg_convex', 'wc_gradient_descent_qg_convex',
            'gradient_descent_qg_convex_decreasing', 'wc_gradient_descent_qg_convex_decreasing',
@@ -35,12 +37,12 @@ __all__ = ['accelerated_gradient_convex', 'wc_accelerated_gradient_convex',
            'inexact_accelerated_gradient', 'wc_inexact_accelerated_gradient',
            'inexact_gradient_descent', 'wc_inexact_gradient_descent',
            'inexact_gradient_exact_line_search', 'wc_inexact_gradient_exact_line_search',
+           'information_theoretic_exact_method', 'wc_information_theoretic',
            'optimized_gradient', 'wc_optimized_gradient',
+           'optimized_gradient_for_gradient', 'wc_optimized_gradient_for_gradient',
            'proximal_point', 'wc_proximal_point',
            'robust_momentum', 'wc_robust_momentum',
            'subgradient_method', 'wc_subgradient_method',
            'subgradient_method_rsi_eb', 'wc_subgradient_method_rsi_eb',
            'triple_momentum', 'wc_triple_momentum',
-           'information_theoretic_exact_method', 'wc_information_theoretic',
-           'optimized_gradient_for_gradient', 'wc_optimized_gradient_for_gradient',
            ]
