@@ -1,6 +1,7 @@
 from PEPit.point import Point
 from PEPit.expression import Expression
 from PEPit.constraint import Constraint
+from PEPit.psd_matrix import PSDMatrix
 
 from PEPit.tools.dict_operations import merge_dict, prune_dict
 
@@ -108,6 +109,7 @@ class Function(object):
         self.list_of_stationary_points = list()
         self.list_of_points = list()
         self.list_of_constraints = list()
+        self.list_of_psd = list()
 
     def get_is_leaf(self):
         """
@@ -254,6 +256,23 @@ class Function(object):
         # Add constraint to the list of self's constraints
         self.list_of_constraints.append(constraint)
 
+    def add_psd_matrix(self, matrix_of_expressions):
+        """
+        Store a new matrix of :class:`Expression`\s that we enforce to be positive semidefinite.
+
+        Args:
+            matrix_of_expressions (Iterable of Iterable of Expression): a square matrix of :class:`Expression`.
+
+        Raises:
+            AssertionError: if provided matrix is not a square matrix.
+            TypeError: if provided matrix does not contain only Expressions.
+
+        """
+        matrix = PSDMatrix(matrix_of_expressions=matrix_of_expressions)
+
+        # Add constraint to the list of self's constraints
+        self.list_of_psd.append(matrix)
+
     def add_class_constraints(self):
         """
         Warnings:
